==> openGion_dev_5.8.1.1.zip: opengion/uap/webapps/ge/db/oracle/sql/install/01_TABLE/GE20S.sql <==
/****************************************************************************/
/* GE20 ( ﾕｰｻﾞｰﾛｰﾙ設定値ﾃｰﾌﾞﾙ )                                             */
/*                                                                          */
/* Created : 2014/08/09 15:22:59                                            */
/****************************************************************************/
CREATE TABLE GE20 (
   SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , USERID       VARCHAR2 (   10 )                   NOT NULL            /*  20 ﾕｰｻﾞｰID  */
 , ROLES        VARCHAR2 (  500 )                   NOT NULL            /*  30 ﾛｰﾙｽﾞ    */
 , PARAM_ID     VARCHAR2 (   50 )                   NOT NULL            /*  40 ﾊﾟﾗﾒｰﾀID */
 , PARAM        VARCHAR2 ( 4000 )                                       /*  50 設定値   */
 , KBSET        VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /*  60 設定区分 */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時 */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG   */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員 */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時 */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

CREATE SEQUENCE GE20S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GE20T00 
  BEFORE INSERT ON GE20
  FOR EACH ROW 
  BEGIN 
    SELECT GE20S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion_dev_5.9.2.0.zip: opengion/uap/webapps/ge/db/oracle/sql/install/01_TABLE/GE20S.sql <==
/****************************************************************************/
/* GE20 ( ﾕｰｻﾞｰﾛｰﾙ設定値ﾃｰﾌﾞﾙ )                                             */
/*                                                                          */
/* Created : 2015/10/28 15:14:25                                            */
/****************************************************************************/
CREATE TABLE GE20 (
   SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , USERID       VARCHAR2 (   10 )                   NOT NULL            /*  20 ﾕｰｻﾞｰID  */
 , ROLES        VARCHAR2 (  500 )                   NOT NULL            /*  30 ﾛｰﾙｽﾞ    */
 , PARAM_ID     VARCHAR2 (   50 )                   NOT NULL            /*  40 ﾊﾟﾗﾒｰﾀID */
 , PARAM        VARCHAR2 ( 4000 )                                       /*  50 設定値   */
 , KBSET        VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /*  60 設定区分 */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時 */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG   */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員 */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時 */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GE20S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GE20T00 
  BEFORE INSERT ON GE20
  FOR EACH ROW 
  BEGIN 
    SELECT GE20S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
